@@ -59,6 +59,8 @@
 G_DEFINE_TYPE (PeasEngine, peas_engine, G_TYPE_OBJECT);
 
 static PeasEngine *default_engine = NULL;
+static gboolean shutdown = FALSE;
+static GHashTable *loaders = NULL;
 
 /* Signals */
 enum {
@@ -101,9 +103,6 @@ static void peas_engine_load_plugin_real   (PeasEngine     *engine,
 static void peas_engine_unload_plugin_real (PeasEngine     *engine,
                                             PeasPluginInfo *info);
 
-static gboolean shutdown = FALSE;
-static GHashTable *loaders = NULL;
-
 static void
 load_plugin_info (PeasEngine  *engine,
                   const gchar *filename,
@@ -299,8 +298,6 @@ peas_engine_init (PeasEngine *engine)
                                               PeasEnginePrivate);
 
   engine->priv->in_dispose = FALSE;
-
-  peas_engine_enable_loader (engine, "C");
 }
 
 static void
@@ -575,6 +572,9 @@ peas_engine_class_init (PeasEngineClass *klass)
                                    (GEqualFunc) equal_lowercase,
                                    (GDestroyNotify) g_free,
                                    (GDestroyNotify) loader_destroy);
+
+  /* The C plugin loader is always enabled */
+  g_hash_table_insert (loaders, g_strdup ("C"), g_new0 (LoaderInfo, 1));
 }
 
 static PeasObjectModule *
@@ -733,6 +733,9 @@ compare_plugin_info_and_name (PeasPluginInfo *info,
  * @engine: A #PeasEngine.
  * @plugin_name: A plugin name.
  *
+ * Gets the #PeasPluginInfo corresponding with @plugin_name,
+ * or %NULL if @plugin_name was not found.
+ *
  * Returns: the #PeasPluginInfo corresponding with
  * a given plugin module name.
  */
@@ -778,7 +781,7 @@ load_plugin (PeasEngine     *engine,
       if (!dep_info)
         {
           g_warning ("Could not find plugin '%s' for plugin '%s'",
-                     dependencies[i], info->name);
+                     dependencies[i], peas_plugin_info_get_module_name (info));
           g_set_error (&info->error,
                        PEAS_PLUGIN_INFO_ERROR,
                        PEAS_PLUGIN_INFO_ERROR_DEP_NOT_FOUND,
@@ -793,7 +796,7 @@ load_plugin (PeasEngine     *engine,
                        PEAS_PLUGIN_INFO_ERROR,
                        PEAS_PLUGIN_INFO_ERROR_LOADING_FAILED,
                        _("Dependency '%s' failed to load"),
-                       dep_info->name);
+                       peas_plugin_info_get_name (dep_info));
           goto error;
         }
     }
@@ -803,7 +806,7 @@ load_plugin (PeasEngine     *engine,
   if (loader == NULL)
     {
       g_warning ("Could not find loader '%s' for plugin '%s'",
-                 info->loader, info->name);
+                 info->loader, peas_plugin_info_get_module_name (info));
       g_set_error (&info->error,
                    PEAS_PLUGIN_INFO_ERROR,
                    PEAS_PLUGIN_INFO_ERROR_LOADER_NOT_FOUND,
@@ -814,7 +817,8 @@ load_plugin (PeasEngine     *engine,
 
   if (!peas_plugin_loader_load (loader, info))
     {
-      g_warning ("Error loading plugin '%s'", info->name);
+      g_warning ("Error loading plugin '%s'",
+                 peas_plugin_info_get_module_name (info));
       g_set_error (&info->error,
                    PEAS_PLUGIN_INFO_ERROR,
                    PEAS_PLUGIN_INFO_ERROR_LOADING_FAILED,
@@ -822,7 +826,7 @@ load_plugin (PeasEngine     *engine,
       goto error;
     }
 
-  g_debug ("Loaded plugin '%s'", info->module_name);
+  g_debug ("Loaded plugin '%s'", peas_plugin_info_get_module_name (info));
 
   return TRUE;
 
@@ -906,7 +910,7 @@ peas_engine_unload_plugin_real (PeasEngine     *engine,
   peas_plugin_loader_garbage_collect (loader);
   peas_plugin_loader_unload (loader, info);
 
-  g_debug ("Unloaded plugin '%s'", info->module_name);
+  g_debug ("Unloaded plugin '%s'", peas_plugin_info_get_module_name (info));
 
   if (!engine->priv->in_dispose)
     g_object_notify (G_OBJECT (engine), "loaded-plugins");
@@ -938,6 +942,17 @@ peas_engine_unload_plugin (PeasEngine     *engine,
   return !peas_plugin_info_is_loaded (info);
 }
 
+/**
+ * peas_engine_provides_extension:
+ * @engine: A #PeasEngine.
+ * @info: A #PeasPluginInfo.
+ * @extension_type: The extension #GType.
+ *
+ * Returns if @info provides an extension for @extension_type.
+ * If the @info is not loaded than %FALSE will always be returned.
+ *
+ * Returns: if @info provides an extension for @extension_type.
+ */
 gboolean
 peas_engine_provides_extension (PeasEngine     *engine,
                                 PeasPluginInfo *info,
@@ -995,7 +1010,7 @@ peas_engine_create_extensionv (PeasEngine     *engine,
   extension = peas_plugin_loader_create_extension (loader, info, extension_type,
                                                    n_parameters, parameters);
 
-  if (!PEAS_IS_EXTENSION (extension))
+  if (!G_TYPE_CHECK_INSTANCE_TYPE (extension, extension_type))
     {
       g_warning ("Plugin '%s' does not provide a '%s' extension",
                  peas_plugin_info_get_module_name (info),
@@ -1069,7 +1084,7 @@ peas_engine_create_extension_valist (PeasEngine     *engine,
  * @info: A loaded #PeasPluginInfo.
  * @extension_type: The implemented extension #GType.
  * @first_property: the name of the first property.
- * @Varargs: the value of the first property, followed optionally by more
+ * @...: the value of the first property, followed optionally by more
  *   name/value pairs, followed by %NULL.
  *
  * If the plugin identified by @info implements the @extension_type interface,
